@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Exporter qw(app_base app_fuzzy app_strict option parameter);
@@ -81,9 +81,8 @@ sub new_with_command {
     }
     
     # Get ARGV
-    my $parsed_argv = MooseX::App::ParsedArgv->new;
-    $parsed_argv->argv(\@ARGV);
-    my $first_argv = $parsed_argv->consume('parameters');
+    my $parsed_argv = MooseX::App::ParsedArgv->new();
+    my $first_argv = $parsed_argv->first_argv;
     
     # No args
     if (! defined $first_argv
@@ -96,13 +95,13 @@ sub new_with_command {
             $meta->command_usage_global(),
         );
     # Requested help
-    } elsif (lc($first_argv->key) =~ m/^(help|h|\?|usage)$/) {
+    } elsif (lc($first_argv) =~ m/^(help|h|\?|usage)$/) {
         return MooseX::App::Message::Envelope->new(
             $meta->command_usage_global(),
         );
     # Looks like a command
     } else {
-        my $return = $meta->command_find($first_argv->key);
+        my $return = $meta->command_find($first_argv);
         
         # Nothing found
         if (blessed $return
@@ -317,12 +316,13 @@ Enables fuzzy matching of commands and attributes. Is turned on by default.
 
 =head2 app_strict
 
- app_strict(1); # default 
+ app_strict(0); # default 
  OR
- app_strict(0);
+ app_strict(1); 
 
 If strict is enabled the programm will terminate with an error message if
-superfluous/unknown parameters and options are supplied.
+superfluous/unknown positional parameters are supplied. If disabled all 
+extra parameters will be copied to the L<extra_argv> attribute.
 
 =head2 app_command_name
 
@@ -335,6 +335,18 @@ superfluous/unknown parameters and options are supplied.
 This sub can be used to control how package names should be translated
 to command names.
 
+=head1 GLOBAL ATTRIBUTES
+
+All MooseX::App classes will have two extra attributes/accessors
+
+=head2 extra_argv
+
+Carries all parameters from @ARGV that were not consumed.
+
+=head2 help_flag
+
+Help flag option
+
 =head1 ATTRIBUTE OPTIONS
 
 =over
