@@ -65,12 +65,19 @@ sub _handle_attribute {
                     || 'MooseX::App::Meta::Role::Attribute::Option' ~~ $local_attributes{traits};
             }
         }
+
         $meta->add_attribute( $attr, %local_attributes );
+
     }
     
     return;
 }
 
+sub app_strict($) {
+    my ( $meta, $value ) = @_;
+    return $meta->app_strict($value);
+}
+
 sub app_fuzzy($) {
     my ( $meta, $value ) = @_;
     return $meta->app_fuzzy($value);
@@ -161,4 +168,4 @@ sub command_usage($) {
     return $meta->command_usage($usage);
 }
 
-1;
\ No newline at end of file
+1;
