@@ -11,6 +11,7 @@ use Moose::Role;
 use MooseX::App::Utils;
 use Path::Class;
 use Module::Pluggable::Object;
+use List::Util qw(max);
 
 has 'app_messageclass' => (
     is          => 'rw',
@@ -33,7 +34,7 @@ has 'app_base' => (
 has 'app_strict' => (
     is          => 'rw',
     isa         => 'Bool',
-    default     => 1,
+    default     => 0,
 );
 
 has 'app_fuzzy' => (
@@ -108,24 +109,20 @@ sub command_args {
     
     my ($return,$errors) = $self->command_parse_options(\@attributes_option);
     
-    if ($self->app_strict) {
-        while (my $option = $parsed_argv->consume('options') ) {
-            unshift(@{$errors},
-                $self->command_message(
-                    header          => "Unknown option '".$option->key."'", # LOCALIZE
-                    type            => "error",
-                )
-            );
-        }
+    foreach my $option ($parsed_argv->available('option')) {
+        unshift(@{$errors},
+            $self->command_message(
+                header          => "Unknown option '".$option->key."'", # LOCALIZE
+                type            => "error",
+            )
+        );
     }
     
     # Process params
-    my @attributes_parameter  = sort { 
-        $a->cmd_position <=> $b->cmd_position
-    } $self->command_usage_attributes($metaclass,'parameter');
+    my @attributes_parameter  = $self->command_usage_attributes($metaclass,'parameter');
 
     foreach my $attribute (@attributes_parameter) {
-        my $value = $parsed_argv->consume('parameters');
+        my $value = $parsed_argv->consume('parameter');
         last
             unless defined $value;
 
@@ -134,8 +131,9 @@ sub command_args {
         $return->{$attribute->name} = $parameter_value;
     }
     
+    # Handle all unconsumed parameters and options
     if ($self->app_strict) {
-        while (my $parameter = $parsed_argv->consume('parameters') ) {
+        foreach my $parameter ($parsed_argv->available('parameter')) {
             unshift(@{$errors},
                 $self->command_message(
                     header          => "Unknown parameter '".$parameter->key."'", # LOCALIZE
@@ -143,7 +141,8 @@ sub command_args {
                 )
             );
         }
-    } 
+    }
+    
     return ($return,$errors);
 }
 
@@ -187,7 +186,7 @@ sub command_parse_options {
     my $parsed_argv = MooseX::App::ParsedArgv->instance;
     
     # Loop all exact matches
-    foreach my $option ($parsed_argv->available('options')) {
+    foreach my $option ($parsed_argv->available('option')) {
         if (my $attribute = $option_to_attribute{$option->key}) {
             $match->{$attribute->name} = $option->value;
             $option->consume($attribute);
@@ -197,7 +196,7 @@ sub command_parse_options {
     # Process fuzzy matches
     if ($self->app_fuzzy) {
         # Loop all options (sorted by length)
-        foreach my $option (sort { length($b->key) <=> length($a->key) } $parsed_argv->available('options')) {
+        foreach my $option (sort { length($b->key) <=> length($a->key) } $parsed_argv->available('option')) {
 
             # No fuzzy matching for one-letter flags
             my $option_length = length($option->key);
@@ -476,6 +475,54 @@ sub command_find {
     }
 }
 
+sub command_parser_hints {
+    my ($self,$metaclass) = @_;
+    
+    $metaclass ||= $self;
+    
+    my %hints;
+    my %names;
+    foreach my $attribute ($self->command_usage_attributes($metaclass,[qw(option proto)])) {
+        foreach my $name ($attribute->cmd_name_possible) {
+            $names{$name} = { name => $attribute->name, bool => $attribute->cmd_is_bool };
+            $hints{$name} = $names{$name};
+        }
+    }
+    
+    if ($self->app_fuzzy) {
+        my $length = max(map { length($_) } keys %names);
+        foreach my $l (reverse(1..$length)) {
+            my %tmp;
+            foreach my $name (keys %names) {
+                next
+                    if length($name) < $l;
+                my $short_name = substr($name,0,$l);
+                next
+                    if defined $hints{$short_name};
+                $tmp{$short_name} ||= [];
+                next
+                    if defined $tmp{$short_name}->[0]
+                    && $tmp{$short_name}->[0]->{name} eq $names{$name}->{name};
+                push(@{$tmp{$short_name}},$names{$name})
+            }
+            foreach my $short_name (keys %tmp) {
+                next
+                    if scalar @{$tmp{$short_name}} > 1;
+                $hints{$short_name} = $tmp{$short_name}->[0];
+            }
+        }
+    }
+    
+    my @return;
+    foreach my $name (keys %hints) {
+        next
+            unless defined $hints{$name}->{bool};
+        push(@return,$name);
+    }
+    
+    return \@return;
+}
+
 sub command_message {
     my ($self,@args) = @_;
     my $messageclass = $self->app_messageclass;
@@ -499,7 +546,9 @@ sub command_usage_attributes {
         push(@return,$attribute);
     }
     
-    return @return;
+    return (sort { 
+        $a->cmd_position <=> $b->cmd_position
+    } @return);
 }
 
 sub command_usage_options {
