@@ -8,11 +8,6 @@ use utf8;
 use namespace::autoclean;
 use Moose::Role;
 
-has extra_argv => (
-    is => 'rw', 
-    isa => 'ArrayRef', 
-);
-
 #has ARGV => (
 #    is => 'rw', 
 #    isa => 'ArrayRef', 
@@ -29,16 +24,14 @@ sub initialize_command_class {
     my ($ok,$error) = Class::Load::try_load_class($command_class);
     unless ($ok) {
         Moose->throw_error($error);
-#        return MooseX::App::Message::Envelope->new(
-#            $meta->command_message(
-#                header          => $error,
-#                type            => "error",
-#            ),
-#            $meta->command_usage_global(),
-#        );
     }
     
     my $command_meta = $command_class->meta || $meta;
+    
+    my $parsed_argv = MooseX::App::ParsedArgv->instance();
+    $parsed_argv->fuzzy($meta->app_fuzzy);
+    $parsed_argv->hints($meta->command_parser_hints($command_meta));
+    
     my ($proto_result,$proto_errors) = $meta->command_proto($command_meta);
     
     # TODO return some kind of null class object
@@ -86,7 +79,7 @@ sub initialize_command_class {
     
     my $command_object = $command_class->new(
         %params,
-        extra_argv          => MooseX::App::ParsedArgv->instance->extra,
+        extra_argv          => [ $parsed_argv->extra ],
     );
       
     if (scalar @errors) {
